﻿using System.Collections.ObjectModel;
using GalaSoft.MvvmLight.Command;
using System;
using GalaSoft.MvvmLight;

namespace RibbonBarDataBinding.ViewModels
{
	public class MainViewModel : ViewModelBase
	{
		private TabViewModel selectedTab;

		public MainViewModel()
		{
			Tabs = new ObservableCollection<TabViewModel>();
			Tabs.Add(new TabViewModel() { Text = "One" });
			Tabs.Add(new TabViewModel() { Text = "Two" });
			Tabs.Add(new TabViewModel() { Text = "Three" });

			var groups = Tabs[0].Groups;
			groups.Add(new GroupViewModel() { Text = "One2" });
			groups.Add(new GroupViewModel() { Text = "Two2" });
			groups.Add(new GroupViewModel() { Text = "Three2" });
			groups.Add(new GroupViewModel() { Text = "Four2" });

			var groupItems = groups[0].Buttons;
			groupItems.Add(new ButtonViewModel()
			{
				Text = "button 1",
				SmallImage = new Uri("Analyze.png", UriKind.Relative),
				LargeImage = new Uri("Add.png", UriKind.Relative)
			});
			groupItems.Add(new ButtonViewModel()
			{
				Text = "button 2",
				SmallImage = new Uri("Analyze.png", UriKind.Relative),
				LargeImage = new Uri("Add.png", UriKind.Relative)
			});
			groupItems.Add(new ButtonViewModel()
			{
				Text = "button 3",
				SmallImage = new Uri("Analyze.png", UriKind.Relative),
				LargeImage = new Uri("Add.png", UriKind.Relative)
			});
			groupItems.Add(new ButtonViewModel()
			{
				Text = "button 4",
				SmallImage = new Uri("Analyze.png", UriKind.Relative),
				LargeImage = new Uri("Add.png", UriKind.Relative)
			});

			QuickAccessItems = new ObservableCollection<ButtonViewModel>();
			QuickAccessItems.Add(new ButtonViewModel() { Text = "One3" });
			QuickAccessItems.Add(new ButtonViewModel() { Text = "Two3" });
			QuickAccessItems.Add(new ButtonViewModel() { Text = "Three3" });
			QuickAccessItems.Add(new ButtonViewModel() { Text = "Four3" });

			ApplicationMenuItems = new ObservableCollection<ButtonViewModel>();
			ApplicationMenuItems.Add(new ButtonViewModel() { Text = "One3" });
			ApplicationMenuItems.Add(new ButtonViewModel() { Text = "Two3" });
			ApplicationMenuItems.Add(new ButtonViewModel() { Text = "Three3" });
			ApplicationMenuItems.Add(new ButtonViewModel() { Text = "Four3" });

			ContextualTabs1 = new ObservableCollection<TabViewModel>();
			ContextualTabs1.Add(new TabViewModel() { Text = "ContextualTab1One" });
			ContextualTabs1.Add(new TabViewModel() { Text = "ContextualTab1Two" });
			ContextualTabs1.Add(new TabViewModel() { Text = "ContextualTab1Three" });
			ContextualTabs1.Add(new TabViewModel() { Text = "ContextualTab1Four" });

			ContextualTabs2 = new ObservableCollection<TabViewModel>();
			ContextualTabs2.Add(new TabViewModel() { Text = "ContextualTab2One" });
			ContextualTabs2.Add(new TabViewModel() { Text = "ContextualTab2Two" });
			ContextualTabs2.Add(new TabViewModel() { Text = "ContextualTab2Three" });
			ContextualTabs2.Add(new TabViewModel() { Text = "ContextualTab2Four" });

			this.selectedTab = this.Tabs[1];

			AddTab = new RelayCommand(() => this.Tabs.Add(new TabViewModel() { Text = "New tab" }));
			AddGroup = new RelayCommand(() =>
										{
											var tab = (new Random()).Next(this.Tabs.Count);
											this.Tabs[tab].Groups.Add(new GroupViewModel { Text = "New group" });
										});
			AddButton = new RelayCommand(() =>
				{
					var tab = (new Random()).Next(this.Tabs.Count);
					if (this.Tabs[tab].Groups.Count > 0)
					{
						var group = (new Random()).Next(this.Tabs[tab].Groups.Count);
						this.Tabs[tab].Groups[group].Buttons.Add(new ButtonViewModel() { Text = "New button" });
					}
				});

			RemoveTab = new RelayCommand(() =>
				{
					if (this.Tabs.Count > 0)
						this.Tabs.RemoveAt(0);
				}
			);
			SelectFirst = new RelayCommand(() =>
				{
					this.SelectedTab = this.Tabs[0];
				}
			);
		}

		public ObservableCollection<TabViewModel> Tabs
		{
			get;
			private set;
		}

		public ObservableCollection<ButtonViewModel> QuickAccessItems
		{
			get;
			private set;
		}

		public ObservableCollection<ButtonViewModel> ApplicationMenuItems
		{
			get;
			private set;
		}

		
		public ObservableCollection<TabViewModel> ContextualTabs1 { get; set; }
		public ObservableCollection<TabViewModel> ContextualTabs2 { get; set; }


		public TabViewModel SelectedTab
		{
			get
			{
				return this.selectedTab;
			}
			set
			{
				if (this.selectedTab != value)
				{
					this.selectedTab = value;
					RaisePropertyChanged("SelectedTab");
				}
			}
		}

		public RelayCommand AddTab
		{
			get;
			private set;
		}

		public RelayCommand AddGroup
		{
			get;
			private set;
		}

		public RelayCommand AddButton
		{
			get;
			private set;
		}

		public RelayCommand RemoveTab
		{
			get;
			private set;
		}
		public RelayCommand SelectFirst
		{
			get;
			private set;
		}
	}
}
